==> nextcloud-22.2.9.tgz: nextcloud/apps/dav/l10n/zh_TW.js <==
OC.L10N.register(
    "dav",
    {
    "Calendar" : "日曆",
    "Todos" : "待辦事項",
    "Personal" : "個人",
    "{actor} created calendar {calendar}" : "{actor} 建立了日曆 {calendar}",
    "You created calendar {calendar}" : "您建立了日曆 {calendar}",
    "{actor} deleted calendar {calendar}" : "{actor} 刪除了日曆 {calendar}",
    "You deleted calendar {calendar}" : "您刪除了日曆 {calendar}",
    "{actor} updated calendar {calendar}" : "{actor} 更新了日曆 {calendar}",
    "You updated calendar {calendar}" : "您更新了日曆 {calendar}",
    "{actor} restored calendar {calendar}" : "{actor} 復原了日曆 {calendar}",
    "You restored calendar {calendar}" : "您復原了日曆 {calendar}",
    "You shared calendar {calendar} as public link" : "您將 {calendar} 日曆以公開連結分享",
    "You removed public link for calendar {calendar}" : "您刪除了 {calendar} 的公開分享連結",
    "{actor} shared calendar {calendar} with you" : "{actor} 與您分享了 {calendar} 日曆",
    "You shared calendar {calendar} with {user}" : "您與 {user} 分享了 {calendar} 日曆",
    "{actor} shared calendar {calendar} with {user}" : "{actor} 與 {user} 分享了日曆 {calendar}",
    "{actor} unshared calendar {calendar} from you" : "{actor} 停止與您分享日曆 {calendar}",
    "You unshared calendar {calendar} from {user}" : "您停止與 {user} 分享日曆 {calendar}",
    "{actor} unshared calendar {calendar} from {user}" : "{actor} 停止與 {user} 分享日曆 {calendar}",
    "{actor} unshared calendar {calendar} from themselves" : "{actor} 停止與他們自己分享日曆 {calendar}",
    "You shared calendar {calendar} with group {group}" : "您與群組 {group} 分享了日曆 {calendar}",
    "{actor} shared calendar {calendar} with group {group}" : "{actor} 與群組 {group} 分享了日曆 {calendar}",
    "You unshared calendar {calendar} from group {group}" : "您已停止與群組 {group} 分享日曆 {calendar}",
    "{actor} unshared calendar {calendar} from group {group}" : "{actor} 已停止與群組 {group} 分享日曆 {calendar}",
    "Untitled event" : "未命名活動",
    "{actor} created event {event} in calendar {calendar}" : "{actor} 在日曆 {calendar} 中建立了 {event} 活動",
    "You created event {event} in calendar {calendar}" : "您在日曆 {calendar} 中建立了 {event} 活動",
    "{actor} deleted event {event} from calendar {calendar}" : "{actor} 在日曆 {calendar} 中刪除了 {event} 活動",
    "You deleted event {event} from calendar {calendar}" : "您在日曆 {calendar} 中刪除了 {event} 活動",
    "{actor} updated event {event} in calendar {calendar}" : "{actor} 在日曆 {calendar} 中更新了 {event} 活動",
    "You updated event {event} in calendar {calendar}" : "您在日曆 {calendar} 中刪除了 {event} 活動",
    "{actor} moved event {event} from calendar {sourceCalendar} to calendar {targetCalendar}" : "{actor} 將事件 {event} 從行事曆 {sourceCalendar} 移動至行事曆 {targetCalendar}",
    "You moved event {event} from calendar {sourceCalendar} to calendar {targetCalendar}" : "您將事件 {event} 從行事曆 {sourceCalendar} 移動至行事曆 {targetCalendar}",
    "{actor} restored event {event} of calendar {calendar}" : "{actor} 復原了日曆 {calendar} 中的活動 {event}",
    "You restored event {event} of calendar {calendar}" : "您復原了日曆 {calendar} 中的活動 {event}",
    "Busy" : "忙碌",
    "{actor} created todo {todo} in list {calendar}" : "{actor} 在列表 {calendar} 中建立了待辦事項 {todo}",
    "You created todo {todo} in list {calendar}" : "您在列表 {calendar} 中建立了待辦事項 {todo}",
    "{actor} deleted todo {todo} from list {calendar}" : "{actor} 在列表 {calendar} 中刪除了待辦事項 {todo}",
    "You deleted todo {todo} from list {calendar}" : "您在列表 {calendar} 中刪除了待辦事項 {todo}",
    "{actor} updated todo {todo} in list {calendar}" : "{actor} 在列表 {calendar} 中更新了待辦事項 {todo}",
    "You updated todo {todo} in list {calendar}" : "您在列表 {calendar} 中更新了待辦事項 {todo}",
    "{actor} solved todo {todo} in list {calendar}" : "{actor} 在列表 {calendar} 中解決了待辦事項 {todo}",
    "You solved todo {todo} in list {calendar}" : "您在列表 {calendar} 中解決了待辦事項 {todo}",
    "{actor} reopened todo {todo} in list {calendar}" : "{actor} 在列表 {calendar} 中重新開啟了待辦事項 {todo}",
    "You reopened todo {todo} in list {calendar}" : "您在列表 {calendar} 中重新開啟了待辦事項 {todo}",
    "{actor} moved todo {todo} from list {sourceCalendar} to list {targetCalendar}" : "{actor} 將待辦事項 {todo} 從清單 {sourceCalendar} 移動至清單 {targetCalendar}",
    "You moved todo {todo} from list {sourceCalendar} to list {targetCalendar}" : "您將待辦事項 {todo} 從清單 {sourceCalendar} 移動至清單 {targetCalendar}",
    "Calendar, contacts and tasks" : "日曆、通訊錄與工作項目",
    "A <strong>calendar</strong> was modified" : "一個<strong>日曆</strong>被更動",
    "A calendar <strong>event</strong> was modified" : "一個日曆<strong>活動</strong>被更動",
    "A calendar <strong>todo</strong> was modified" : "一個日曆<strong>待辦事項</strong>被更動",
    "Contact birthdays" : "聯絡人生日",
    "Death of %s" : "%s 逝世",
    "Calendar:" : "日曆：",
    "Date:" : "日期：",
    "Where:" : "地點：",
    "Description:" : "描述：",
    "_%n year_::_%n years_" : ["%n年"],
    "_%n month_::_%n months_" : ["%n月"],
    "_%n day_::_%n days_" : ["%n天"],
    "_%n hour_::_%n hours_" : ["%n小時"],
    "_%n minute_::_%n minutes_" : ["%n分鐘"],
    "%s (in %s)" : "%s（在 %s）",
    "%s (%s ago)" : "%s（%s 前）",
    "Calendar: %s" : "日曆：%s",
    "Date: %s" : "日期：%s",
    "Description: %s" : "描述：%s",
    "Where: %s" : "地點：%s",
    "%1$s via %2$s" : "%1$s 由 %2$s",
    "Cancelled: %1$s" : "已取消：%1$s",
    "Invitation canceled" : "邀請已取消",
    "Re: %1$s" : "回覆：%1$s",
    "Invitation updated" : "邀請已更新",
    "Invitation: %1$s" : "邀請：%1$s",
    "Invitation" : "邀請",
    "Title:" : "標題：",
    "Time:" : "時間：",
    "Location:" : "地點：",
    "Link:" : "連結：",
    "Organizer:" : "組織者：",
    "Attendees:" : "參與者：",
    "Accept" : "接受",
    "Decline" : "拒絕",
    "More options …" : "更多選項……",
    "More options at %s" : "%s 有更多選項",
    "Contacts" : "聯絡人",
    "{actor} created address book {addressbook}" : "{actor} 建立了通訊錄 {addressbook}",
    "You created address book {addressbook}" : "您建立了通訊錄 {addressbook}",
    "{actor} deleted address book {addressbook}" : "{actor} 刪除了通訊錄 {addressbook}",
    "You deleted address book {addressbook}" : "您刪除了通訊錄 {addressbook}",
    "{actor} updated address book {addressbook}" : "{actor} 更新了通訊錄 {addressbook}",
    "You updated address book {addressbook}" : "您更新了通訊錄 {addressbook}",
    "{actor} shared address book {addressbook} with you" : "{actor} 與您分享了通訊錄 {addressbook}",
    "You shared address book {addressbook} with {user}" : "您與 {user} 分享了通訊錄 {addressbook}",
    "{actor} shared address book {addressbook} with {user}" : "{actor} 與 {user} 分享了通訊錄 {addressbook}",
    "{actor} unshared address book {addressbook} from you" : "{actor} 取消與您分享通訊錄 {addressbook}",
    "You unshared address book {addressbook} from {user}" : "您取消與 {user} 分享的通訊錄 {addressbook}",
    "{actor} unshared address book {addressbook} from {user}" : "{actor} 取消與 {user} 分享通訊錄 {addressbook}",
    "{actor} unshared address book {addressbook} from themselves" : "{actor} 取消與他們自己分享的通訊錄 {addressbook}",
    "You shared address book {addressbook} with group {group}" : "您與群組 {group} 分享了通訊錄 {addressbook}",
    "{actor} shared address book {addressbook} with group {group}" : "{actor} 與群組 {group} 分享了通訊錄 {addressbook}",
    "You unshared address book {addressbook} from group {group}" : "您取消與群組 {group} 分享的通訊錄 {addressbook}",
    "{actor} unshared address book {addressbook} from group {group}" : "{actor} 取消與群組 {group} 分享的通訊錄 {addressbook}",
    "{actor} created contact {card} in address book {addressbook}" : "{actor} 在通訊錄 {addressbook} 中建立了聯絡人 {card}",
    "You created contact {card} in address book {addressbook}" : "您在通訊錄 {addressbook} 中建立了聯絡人 {card}",
    "{actor} deleted contact {card} from address book {addressbook}" : "{actor} 從通訊錄 {addressbook} 刪除了聯絡人 {card}",
    "You deleted contact {card} from address book {addressbook}" : "您從通訊錄 {addressbook} 刪除了聯絡人 {card}",
    "{actor} updated contact {card} in address book {addressbook}" : "{actor} 在通訊錄 {addressbook} 中更新了聯絡人 {card}",
    "You updated contact {card} in address book {addressbook}" : "您在通訊錄 {addressbook} 中更新了聯絡人 {card}",
    "A <strong>contact</strong> or <strong>address book</strong> was modified" : "<strong>聯絡人</strong>或<strong>通訊錄</strong>已被修改",
    "File is not updatable: %1$s" : "檔案無法更新：%1$s",
    "Could not write to final file, canceled by hook" : "無法寫入最終檔案，被掛勾取消",
    "Could not write file contents" : "無法寫入檔案內容",
    "_%n byte_::_%n bytes_" : ["%n 位元組"],
    "Error while copying file to target location (copied: %1$s, expected filesize: %2$s)" : "將檔案複製到目標位置時發生錯誤（已複製：%1$s，預期的檔案大小：%2$s）",
    "Expected filesize of %1$s but read (from Nextcloud client) and wrote (to Nextcloud storage) %2$s. Could either be a network problem on the sending side or a problem writing to the storage on the server side." : "預期的檔案大小為 %1$s，但讀取（從 Nextcloud 客戶端）與寫入（至 Nextcloud 儲存空間）%2$s。可能是傳送端的網路問題或是伺服器端的儲存空間寫入問題。",
    "Could not rename part file to final file, canceled by hook" : "無法將部份檔案重新命名為最終檔案，被掛勾取消",
    "Could not rename part file to final file" : "無法將部份檔案重新命名為最終檔案",
    "Failed to check file size: %1$s" : "檢查檔案大小失敗：%1$s",
    "Could not open file" : "無法開啟檔案",
    "Encryption not ready: %1$s" : "尚未準備好加密：%1$s",
    "Failed to open file: %1$s" : "開啟檔案失敗：%1$s",
    "Failed to unlink: %1$s" : "解除連結失敗：%1$s",
    "Invalid chunk name" : "無效的區塊名稱",
    "Could not rename part file assembled from chunks" : "無法重新命名從區塊組合成的部份檔案",
    "Failed to write file contents: %1$s" : "寫入檔案內容失敗：%1$s",
    "File not found: %1$s" : "找不到檔案：%1$s",
    "System is in maintenance mode." : "系統處於維護模式。",
    "Upgrade needed" : "需要升級",
    "Your %s needs to be configured to use HTTPS in order to use CalDAV and CardDAV with iOS/macOS." : "您的 %s 必須要設定 HTTPS ，才能在 iOS/macOS 上使用 CalDAV 和 CardDAV。",
    "Configures a CalDAV account" : "設定一個 CalDAV 帳號",
    "Configures a CardDAV account" : "設定一個 CardDAV 帳號",
    "Events" : "活動",
    "Tasks" : "工作項目",
    "Untitled task" : "未命名工作項目",
    "Completed on %s" : "完成於 %s",
    "Due on %s by %s" : "到期於 %s 由 %s",
    "Due on %s" : "到期於 %s",
    "Migrated calendar (%1$s)" : "已導入的行事曆 (%1$s)",
    "Calendars including events, details and attendees" : "行事曆，包含事件、詳細資訊及參與者",
    "Contacts and groups" : "聯絡人與群組",
    "WebDAV" : "WebDAV",
    "WebDAV endpoint" : "WebDAV 端點",
    "Availability" : "可用性",
    "If you configure your working hours, other users will see when you are out of office when they book a meeting." : "若您設定了您的工作時間，其他使用者在預約會議時就會知道您何時不在辦公室。",
    "Time zone:" : "時區：",
    "to" : "到",
    "Delete slot" : "刪除欄位",
    "No working hours set" : "未設定工作時間",
    "Add slot" : "新增欄位",
    "Monday" : "週一",
    "Tuesday" : "週二",
    "Wednesday" : "週三",
    "Thursday" : "週四",
    "Friday" : "週五",
    "Saturday" : "週六",
    "Sunday" : "週日",
    "Save" : "儲存",
    "Failed to load availability" : "載入可用性失敗",
    "Saved availability" : "已儲存可用性",
    "Failed to save availability" : "儲存可用性失敗",
    "Calendar server" : "日曆伺服器",
    "Send invitations to attendees" : "發送邀請函給參加者",
    "Automatically generate a birthday calendar" : "自動生成生日日曆",
    "Birthday calendars will be generated by a background job." : "生日日曆將由背景作業生成。",
    "Hence they will not be available immediately after enabling but will show up after some time." : "因此，啟用後不會立即可用，但會在一段時間後顯示。",
    "Send notifications for events" : "傳送活動通知",
    "Notifications are sent via background jobs, so these must occur often enough." : "通知會透過背景作業傳送，因此這些會經常發生。",
    "Send reminder notifications to calendar sharees as well" : "也向共享行事曆傳送提醒通知",
    "Reminders are always sent to organizers and attendees." : "一律傳送提醒給舉辦者與參與者。",
    "Enable notifications for events via push" : "啟用推播活動通知",
    "Also install the {calendarappstoreopen}Calendar app{linkclose}, or {calendardocopen}connect your desktop & mobile for syncing ↗{linkclose}." : "也安裝{calendarappstoreopen}日曆應用程式{linkclose}，或{calendardocopen}連結您的電腦或行動裝置以供同步 ↗{linkclose}。",
    "Please make sure to properly set up {emailopen}the email server{linkclose}." : "請確定您正確設定了{emailopen}電子郵件伺服器{linkclose}。",
    "There was an error updating your attendance status." : "更新您的參與狀態時發生錯誤。",
    "Please contact the organizer directly." : "請直接聯絡主辦人。",
    "Are you accepting the invitation?" : "您接受邀請嗎？",
    "Tentative" : "暫定",
    "Number of guests" : "訪客數量",
    "Comment" : "留言",
    "Your attendance was updated successfully." : "您的參與狀態成功更新。"
},
"nplurals=1; plural=0;");

==> nextcloud-23.0.3.tgz: nextcloud/apps/dav/l10n/zh_TW.js <==
OC.L10N.register(
    "dav",
    {
    "Calendar" : "日曆",
    "Todos" : "待辦事項",
    "Personal" : "個人",
    "{actor} created calendar {calendar}" : "{actor} 建立了日曆 {calendar}",
    "You created calendar {calendar}" : "您建立了日曆 {calendar}",
    "{actor} deleted calendar {calendar}" : "{actor} 刪除了日曆 {calendar}",
    "You deleted calendar {calendar}" : "您刪除了日曆 {calendar}",
    "{actor} updated calendar {calendar}" : "{actor} 更新了日曆 {calendar}",
    "You updated calendar {calendar}" : "您更新了日曆 {calendar}",
    "{actor} restored calendar {calendar}" : "{actor} 復原了日曆 {calendar}",
    "You restored calendar {calendar}" : "您復原了日曆 {calendar}",
    "You shared calendar {calendar} as public link" : "您將 {calendar} 日曆以公開連結分享",
    "You removed public link for calendar {calendar}" : "您刪除了 {calendar} 的公開分享連結",
    "{actor} shared calendar {calendar} with you" : "{actor} 與您分享了 {calendar} 日曆",
    "You shared calendar {calendar} with {user}" : "您與 {user} 分享了 {calendar} 日曆",
    "{actor} shared calendar {calendar} with {user}" : "{actor} 與 {user} 分享了日曆 {calendar}",
    "{actor} unshared calendar {calendar} from you" : "{actor} 停止與您分享日曆 {calendar}",
    "You unshared calendar {calendar} from {user}" : "您停止與 {user} 分享日曆 {calendar}",
    "{actor} unshared calendar {calendar} from {user}" : "{actor} 停止與 {user} 分享日曆 {calendar}",
    "{actor} unshared calendar {calendar} from themselves" : "{actor} 停止與他們自己分享日曆 {calendar}",
    "You shared calendar {calendar} with group {group}" : "您與群組 {group} 分享了日曆 {calendar}",
    "{actor} shared calendar {calendar} with group {group}" : "{actor} 與群組 {group} 分享了日曆 {calendar}",
    "You unshared calendar {calendar} from group {group}" : "您已停止與群組 {group} 分享日曆 {calendar}",
    "{actor} unshared calendar {calendar} from group {group}" : "{actor} 已停止與群組 {group} 分享日曆 {calendar}",
    "{actor} created event {event} in calendar {calendar}" : "{actor} 在日曆 {calendar} 中建立了 {event} 活動",
    "You created event {event} in calendar {calendar}" : "您在日曆 {calendar} 中建立了 {event} 活動",
    "{actor} deleted event {event} from calendar {calendar}" : "{actor} 在日曆 {calendar} 中刪除了 {event} 活動",
    "You deleted event {event} from calendar {calendar}" : "您在日曆 {calendar} 中刪除了 {event} 活動",
    "{actor} updated event {event} in calendar {calendar}" : "{actor} 在日曆 {calendar} 中更新了 {event} 活動",
    "You updated event {event} in calendar {calendar}" : "您在日曆 {calendar} 中刪除了 {event} 活動",
    "{actor} restored event {event} of calendar {calendar}" : "{actor} 復原了日曆 {calendar} 中的活動 {event}",
    "You restored event {event} of calendar {calendar}" : "您復原了日曆 {calendar} 中的活動 {event}",
    "Busy" : "忙碌",
    "{actor} created todo {todo} in list {calendar}" : "{actor} 在列表 {calendar} 中建立了待辦事項 {todo}",
    "You created todo {todo} in list {calendar}" : "您在列表 {calendar} 中建立了待辦事項 {todo}",
    "{actor} deleted todo {todo} from list {calendar}" : "{actor} 在列表 {calendar} 中刪除了待辦事項 {todo}",
    "You deleted todo {todo} from list {calendar}" : "您在列表 {calendar} 中刪除了待辦事項 {todo}",
    "{actor} updated todo {todo} in list {calendar}" : "{actor} 在列表 {calendar} 中更新了待辦事項 {todo}",
    "You updated todo {todo} in list {calendar}" : "您在列表 {calendar} 中更新了待辦事項 {todo}",
    "{actor} solved todo {todo} in list {calendar}" : "{actor} 在列表 {calendar} 中解決了待辦事項 {todo}",
    "You solved todo {todo} in list {calendar}" : "您在列表 {calendar} 中解決了待辦事項 {todo}",
    "{actor} reopened todo {todo} in list {calendar}" : "{actor} 在列表 {calendar} 中重新開啟了待辦事項 {todo}",
    "You reopened todo {todo} in list {calendar}" : "您在列表 {calendar} 中重新開啟了待辦事項 {todo}",
    "Calendar, contacts and tasks" : "日曆、通訊錄與工作項目",
    "A <strong>calendar</strong> was modified" : "一個<strong>日曆</strong>被更動",
    "A calendar <strong>event</strong> was modified" : "一個日曆<strong>活動</strong>被更動",
    "A calendar <strong>todo</strong> was modified" : "一個日曆<strong>待辦事項</strong>被更動",
    "Contact birthdays" : "聯絡人生日",
    "Death of %s" : "%s 逝世",
    "Calendar:" : "日曆：",
    "Date:" : "日期：",
    "Where:" : "地點：",
    "Description:" : "描述：",
    "Untitled event" : "未命名活動",
    "_%n year_::_%n years_" : ["%n年"],
    "_%n month_::_%n months_" : ["%n月"],
    "_%n day_::_%n days_" : ["%n天"],
    "_%n hour_::_%n hours_" : ["%n小時"],
    "_%n minute_::_%n minutes_" : ["%n分鐘"],
    "%s (in %s)" : "%s（在 %s）",
    "%s (%s ago)" : "%s（%s 前）",
    "Calendar: %s" : "日曆：%s",
    "Date: %s" : "日期：%s",
    "Description: %s" : "描述：%s",
    "Where: %s" : "地點：%s",
    "%1$s via %2$s" : "%1$s 由 %2$s",
    "Cancelled: %1$s" : "已取消：%1$s",
    "Invitation canceled" : "邀請已取消",
    "Re: %1$s" : "回覆：%1$s",
    "Invitation updated" : "邀請已更新",
    "Invitation: %1$s" : "邀請：%1$s",
    "Invitation" : "邀請",
    "Title:" : "標題：",
    "Time:" : "時間：",
    "Location:" : "地點：",
    "Link:" : "連結：",
    "Organizer:" : "組織者：",
    "Attendees:" : "參與者：",
    "Accept" : "接受",
    "Decline" : "拒絕",
    "More options …" : "更多選項……",
    "More options at %s" : "%s 有更多選項",
    "Contacts" : "聯絡人",
    "{actor} created address book {addressbook}" : "{actor} 建立了通訊錄 {addressbook}",
    "You created address book {addressbook}" : "您建立了通訊錄 {addressbook}",
    "{actor} deleted address book {addressbook}" : "{actor} 刪除了通訊錄 {addressbook}",
    "You deleted address book {addressbook}" : "您刪除了通訊錄 {addressbook}",
    "{actor} updated address book {addressbook}" : "{actor} 更新了通訊錄 {addressbook}",
    "You updated address book {addressbook}" : "您更新了通訊錄 {addressbook}",
    "{actor} shared address book {addressbook} with you" : "{actor} 與您分享了通訊錄 {addressbook}",
    "You shared address book {addressbook} with {user}" : "您與 {user} 分享了通訊錄 {addressbook}",
    "{actor} shared address book {addressbook} with {user}" : "{actor} 與 {user} 分享了通訊錄 {addressbook}",
    "{actor} unshared address book {addressbook} from you" : "{actor} 取消與您分享通訊錄 {addressbook}",
    "You unshared address book {addressbook} from {user}" : "您取消與 {user} 分享的通訊錄 {addressbook}",
    "{actor} unshared address book {addressbook} from {user}" : "{actor} 取消與 {user} 分享通訊錄 {addressbook}",
    "{actor} unshared address book {addressbook} from themselves" : "{actor} 取消與他們自己分享的通訊錄 {addressbook}",
    "You shared address book {addressbook} with group {group}" : "您與群組 {group} 分享了通訊錄 {addressbook}",
    "{actor} shared address book {addressbook} with group {group}" : "{actor} 與群組 {group} 分享了通訊錄 {addressbook}",
    "You unshared address book {addressbook} from group {group}" : "您取消與群組 {group} 分享的通訊錄 {addressbook}",
    "{actor} unshared address book {addressbook} from group {group}" : "{actor} 取消與群組 {group} 分享的通訊錄 {addressbook}",
    "{actor} created contact {card} in address book {addressbook}" : "{actor} 在通訊錄 {addressbook} 中建立了聯絡人 {card}",
    "You created contact {card} in address book {addressbook}" : "您在通訊錄 {addressbook} 中建立了聯絡人 {card}",
    "{actor} deleted contact {card} from address book {addressbook}" : "{actor} 從通訊錄 {addressbook} 刪除了聯絡人 {card}",
    "You deleted contact {card} from address book {addressbook}" : "您從通訊錄 {addressbook} 刪除了聯絡人 {card}",
    "{actor} updated contact {card} in address book {addressbook}" : "{actor} 在通訊錄 {addressbook} 中更新了聯絡人 {card}",
    "You updated contact {card} in address book {addressbook}" : "您在通訊錄 {addressbook} 中更新了聯絡人 {card}",
    "A <strong>contact</strong> or <strong>address book</strong> was modified" : "<strong>聯絡人</strong>或<strong>通訊錄</strong>已被修改",
    "File is not updatable: %1$s" : "檔案無法更新：%1$s",
    "Could not write to final file, canceled by hook" : "無法寫入最終檔案，被掛勾取消",
    "Could not write file contents" : "無法寫入檔案內容",
    "_%n byte_::_%n bytes_" : ["%n 位元組"],
    "Error while copying file to target location (copied: %1$s, expected filesize: %2$s)" : "將檔案複製到目標位置時發生錯誤（已複製：%1$s，預期的檔案大小：%2$s）",
    "Expected filesize of %1$s but read (from Nextcloud client) and wrote (to Nextcloud storage) %2$s. Could either be a network problem on the sending side or a problem writing to the storage on the server side." : "預期的檔案大小為 %1$s，但讀取（從 Nextcloud 客戶端）與寫入（至 Nextcloud 儲存空間）%2$s。可能是傳送端的網路問題或是伺服器端的儲存空間寫入問題。",
    "Could not rename part file to final file, canceled by hook" : "無法將部份檔案重新命名為最終檔案，被掛勾取消",
    "Could not rename part file to final file" : "無法將部份檔案重新命名為最終檔案",
    "Failed to check file size: %1$s" : "檢查檔案大小失敗：%1$s",
    "Could not open file" : "無法開啟檔案",
    "Encryption not ready: %1$s" : "尚未準備好加密：%1$s",
    "Failed to open file: %1$s" : "開啟檔案失敗：%1$s",
    "Failed to unlink: %1$s" : "解除連結失敗：%1$s",
    "Invalid chunk name" : "無效的區塊名稱",
    "Could not rename part file assembled from chunks" : "無法重新命名從區塊組合成的部份檔案",
    "Failed to write file contents: %1$s" : "寫入檔案內容失敗：%1$s",
    "File not found: %1$s" : "找不到檔案：%1$s",
    "System is in maintenance mode." : "系統處於維護模式。",
    "Upgrade needed" : "需要升級",
    "Your %s needs to be configured to use HTTPS in order to use CalDAV and CardDAV with iOS/macOS." : "您的 %s 必須要設定 HTTPS ，才能在 iOS/macOS 上使用 CalDAV 和 CardDAV。",
    "Configures a CalDAV account" : "設定一個 CalDAV 帳號",
    "Configures a CardDAV account" : "設定一個 CardDAV 帳號",
    "Events" : "活動",
    "Tasks" : "工作項目",
    "Untitled task" : "未命名工作項目",
    "Completed on %s" : "完成於 %s",
    "Due on %s by %s" : "到期於 %s 由 %s",
    "Due on %s" : "到期於 %s",
    "Migrated calendar (%1$s)" : "已導入的行事曆 (%1$s)",
    "WebDAV" : "WebDAV",
    "WebDAV endpoint" : "WebDAV 端點",
    "Availability" : "可用性",
    "If you configure your working hours, other users will see when you are out of office when they book a meeting." : "若您設定了您的工作時間，其他使用者在預約會議時就會知道您何時不在辦公室。",
    "Time zone:" : "時區：",
    "to" : "到",
    "Delete slot" : "刪除欄位",
    "No working hours set" : "未設定工作時間",
    "Add slot" : "新增欄位",
    "Monday" : "週一",
    "Tuesday" : "週二",
    "Wednesday" : "週三",
    "Thursday" : "週四",
    "Friday" : "週五",
    "Saturday" : "週六",
    "Sunday" : "週日",
    "Save" : "儲存",
    "Calendar server" : "日曆伺服器",
    "Send invitations to attendees" : "發送邀請函給參加者",
    "Automatically generate a birthday calendar" : "自動生成生日日曆",
    "Birthday calendars will be generated by a background job." : "生日日曆將由背景作業生成。",
    "Hence they will not be available immediately after enabling but will show up after some time." : "因此，啟用後不會立即可用，但會在一段時間後顯示。",
    "Send notifications for events" : "傳送活動通知",
    "Notifications are sent via background jobs, so these must occur often enough." : "通知會透過背景作業傳送，因此這些會經常發生。",
    "Enable notifications for events via push" : "啟用推播活動通知",
    "Also install the {calendarappstoreopen}Calendar app{linkclose}, or {calendardocopen}connect your desktop & mobile for syncing ↗{linkclose}." : "也安裝{calendarappstoreopen}日曆應用程式{linkclose}，或{calendardocopen}連結您的電腦或行動裝置以供同步 ↗{linkclose}。",
    "Please make sure to properly set up {emailopen}the email server{linkclose}." : "請確定您正確設定了{emailopen}電子郵件伺服器{linkclose}。",
    "There was an error updating your attendance status." : "更新您的參與狀態時發生錯誤。",
    "Please contact the organizer directly." : "請直接聯絡主辦人。",
    "Are you accepting the invitation?" : "您接受邀請嗎？",
    "Tentative" : "暫定",
    "Number of guests" : "訪客數量",
    "Comment" : "留言",
    "Your attendance was updated successfully." : "您的參與狀態成功更新。",
    "Calendar and tasks" : "日曆與工作項目"
},
"nplurals=1; plural=0;");
